@@ -21,6 +21,14 @@ ROOM_VNUM_LIMBO = 2
 ROOM_VNUM_TEMPLE = 3001
 ROOM_VNUM_ALTAR = 3054
 ROOM_VNUM_SCHOOL = 3700
+
+# Money objects (ROM C merc.h:1020-1024)
+OBJ_VNUM_SILVER_ONE = 1
+OBJ_VNUM_GOLD_ONE = 2
+OBJ_VNUM_SILVER_SOME = 3
+OBJ_VNUM_GOLD_SOME = 4
+OBJ_VNUM_COINS = 5
+
 # Utility conjuration targets
 OBJ_VNUM_CORPSE_NPC = 10
 OBJ_VNUM_CORPSE_PC = 11
@@ -685,7 +693,7 @@ class WeaponFlag(IntFlag):
     FROST = 1 << 1  # (B) - cold damage
     VAMPIRIC = 1 << 2  # (C) - life drain
     SHARP = 1 << 3  # (D) - critical hits
-    VORPAL = 1 << 4  # (E) - decapitation
+    VORPAL = 1 << 4  # (E) - prevents envenoming (no combat effect in ROM 2.4b6)
     TWO_HANDS = 1 << 5  # (F) - two-handed weapon
     SHOCKING = 1 << 6  # (G) - lightning damage
     POISON = 1 << 7  # (H) - poison effects
